@@ -28,7 +28,7 @@ def taskchecker():
 
     sizechecker("/tmp/counted_services")
     filechecker("/tmp/counted_services")
-    linetotalchecker("/tmp/counted_services", 13000)
+    linetotalchecker("/tmp/counted_services", "13000")
  # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
  
 
