@@ -60,8 +60,8 @@ def linetotalchecker(FILENAME,TOTALNUMBER):
             for x in contents.splitlines():
                 if TOTALNUMBER in x:
                     print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
-            else:
-                print("Counted line might be incorrect")
+                if TOTALNUMBER not in x:
+                    print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
     except FileNotFoundError:
         print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)
         sys.exit(1)
